@@ -1,19 +1,20 @@
 //! Engine events and user defined events container.
 //! 
-//! TODO
-//! 
 use std::sync::{Arc, RwLock};
 use crate::scene::game_object::GameObject;
-use winit::event::Event;
 use std::fmt::Display;
 
+/// A wrapper for winit events.
+/// 
+/// This enum allows for the definition of custom 
+/// events with the UserEvent enumeration constant.
 #[derive(Debug, Clone)]
-pub enum UserEvent<T: 'static + Clone + Send + Sync>{ 
+pub enum UserEvent<T: 'static + Clone + Send + Sync>{
     RebuildSwapchain,
     
     Collision(Arc<RwLock<dyn GameObject>>, Arc<RwLock<dyn GameObject>>),
 
-    WinitEvent(Event<'static, Box<UserEvent<T>>>),
+    WinitEvent(winit::event::Event<'static, Box<UserEvent<T>>>),
     UserEvent(T),
     None,
 }
